#include <stdio.h>
#include <stdlib.h>
#include <glib.h>
#include "../../gems/gems_profile_manager.h"


int *get_user_passwd()
{
	//Should read passwords as strings from profiler


	int user_id;
	gchar *username="Guest";
	gchar *passworddata="password";
	gint dummy_login;
	user_id = gems_profile_manager_get_userid(NULL);
	dummy_login=gems_profile_manager_login(user_id, username,passworddata);
	if(dummy_login)
	{
		//g_print("DUMMY LOGIN BAD\n");
	} else {
		//g_print("DUMMY LOGIN GOOD\n");
	}
	int *pass_arr;
	pass_arr=malloc(4*sizeof*pass_arr);
	pass_arr[0]=1;
	pass_arr[1]=2;
	pass_arr[2]=3;
	pass_arr[3]=6;
	return pass_arr;
}

